==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/usage_billable_summary_body.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


class UsageBillableSummaryBody(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        return {
            "account_billable_usage": (int,),
            "elapsed_usage_hours": (int,),
            "first_billable_usage_hour": (datetime,),
            "last_billable_usage_hour": (datetime,),
            "org_billable_usage": (int,),
            "percentage_in_account": (float,),
            "usage_unit": (str,),
        }

    attribute_map = {
        "account_billable_usage": "account_billable_usage",
        "elapsed_usage_hours": "elapsed_usage_hours",
        "first_billable_usage_hour": "first_billable_usage_hour",
        "last_billable_usage_hour": "last_billable_usage_hour",
        "org_billable_usage": "org_billable_usage",
        "percentage_in_account": "percentage_in_account",
        "usage_unit": "usage_unit",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        Response with properties for each aggregated usage type.

        :param account_billable_usage: The total account usage.
        :type account_billable_usage: int, optional

        :param elapsed_usage_hours: Elapsed usage hours for some billable product.
        :type elapsed_usage_hours: int, optional

        :param first_billable_usage_hour: The first billable hour for the org.
        :type first_billable_usage_hour: datetime, optional

        :param last_billable_usage_hour: The last billable hour for the org.
        :type last_billable_usage_hour: datetime, optional

        :param org_billable_usage: The number of units used within the billable timeframe.
        :type org_billable_usage: int, optional

        :param percentage_in_account: The percentage of account usage the org represents.
        :type percentage_in_account: float, optional

        :param usage_unit: Units pertaining to the usage.
        :type usage_unit: str, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(UsageBillableSummaryBody, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-2.3.0.tar.gz: datadog-api-client-2.3.0/src/datadog_api_client/v1/model/usage_billable_summary_body.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


class UsageBillableSummaryBody(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "account_billable_usage": (int,),
            "elapsed_usage_hours": (int,),
            "first_billable_usage_hour": (datetime,),
            "last_billable_usage_hour": (datetime,),
            "org_billable_usage": (int,),
            "percentage_in_account": (float,),
            "usage_unit": (str,),
        }

    attribute_map = {
        "account_billable_usage": "account_billable_usage",
        "elapsed_usage_hours": "elapsed_usage_hours",
        "first_billable_usage_hour": "first_billable_usage_hour",
        "last_billable_usage_hour": "last_billable_usage_hour",
        "org_billable_usage": "org_billable_usage",
        "percentage_in_account": "percentage_in_account",
        "usage_unit": "usage_unit",
    }

    def __init__(self, *args, **kwargs):
        """
        Response with properties for each aggregated usage type.

        :param account_billable_usage: The total account usage.
        :type account_billable_usage: int, optional

        :param elapsed_usage_hours: Elapsed usage hours for some billable product.
        :type elapsed_usage_hours: int, optional

        :param first_billable_usage_hour: The first billable hour for the org.
        :type first_billable_usage_hour: datetime, optional

        :param last_billable_usage_hour: The last billable hour for the org.
        :type last_billable_usage_hour: datetime, optional

        :param org_billable_usage: The number of units used within the billable timeframe.
        :type org_billable_usage: int, optional

        :param percentage_in_account: The percentage of account usage the org represents.
        :type percentage_in_account: float, optional

        :param usage_unit: Units pertaining to the usage.
        :type usage_unit: str, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(UsageBillableSummaryBody, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
